#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 strict-list
version:              0.1.5
visibility:           public
id:                   strict-list-0.1.5-R9FxLeaQ2F4CMweaZ8mce
key:                  strict-list-0.1.5-R9FxLeaQ2F4CMweaZ8mce
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

abi:                  e84d19ab0c792f6c79fc4fbdc6a8687e
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-8.10.5/site-local/strict-list-0.1.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/strict-list-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/strict-list-0.1.5
hs-libraries:         HSstrict-list-0.1.5-R9FxLeaQ2F4CMweaZ8mce
depends:
    base-4.14.2.0 hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    semigroupoids-5.3.5-CXCAmgAqO2AH1F4bh8bCjo

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

